@@ -42,7 +42,7 @@ class CustomDataset(Dataset):
     ``xxx{img_suffix}`` and ``xxx{seg_map_suffix}`` (extension is also included
     in the suffix). If split is given, then ``xxx`` is specified in txt file.
     Otherwise, all files in ``img_dir/``and ``ann_dir`` will be loaded.
-    Please refer to ``docs/tutorials/new_dataset.md`` for more details.
+    Please refer to ``docs/en/tutorials/new_dataset.md`` for more details.
 
 
     Args:
@@ -349,7 +349,16 @@ class CustomDataset(Dataset):
 
         elif palette is None:
             if self.PALETTE is None:
+                # Get random state before set seed, and restore
+                # random state later.
+                # It will prevent loss of randomness, as the palette
+                # may be different in each iteration if not specified.
+                # See: https://github.com/open-mmlab/mmdetection/issues/5844
+                state = np.random.get_state()
+                np.random.seed(42)
+                # random palette
                 palette = np.random.randint(0, 255, size=(len(class_names), 3))
+                np.random.set_state(state)
             else:
                 palette = self.PALETTE
 
