@@ -175,10 +175,11 @@ class FPN(BaseModule):
             # In some cases, fixing `scale factor` (e.g. 2) is preferred, but
             #  it cannot co-exist with `size` in `F.interpolate`.
             if 'scale_factor' in self.upsample_cfg:
-                laterals[i - 1] += resize(laterals[i], **self.upsample_cfg)
+                laterals[i - 1] = laterals[i - 1] + resize(
+                    laterals[i], **self.upsample_cfg)
             else:
                 prev_shape = laterals[i - 1].shape[2:]
-                laterals[i - 1] += resize(
+                laterals[i - 1] = laterals[i - 1] + resize(
                     laterals[i], size=prev_shape, **self.upsample_cfg)
 
         # build outputs
